unit creg_def;


(* definitionen fuer's parsen der windows-9x registry-hives
   (C)2000-2004 Markus Stephany, merkes_at_mirkes.de, BSD-lizensiert

   Microsoft, Windows, Windows NT sind Markenzeichen der Microsoft
   Corporation.
   NT ist eine Marke von Northern Telecom Limited.


   - v0.01 06.august 2000

   credits an den unbekannten verfasser von winreg.txt
*)


//ansistrings
{$H+}

interface

uses
  dumphive_comm;

const
  // Header-ID's der verschiedenen blcke
  ID_CREG = $47455243; // ID des HIVEs (der Datei) selbst
  ID_RGKN = $4E4B4752; // ID eines RGKN-Blocks
  ID_RGDB = $42444752; // ID eines RGDB-Blocks

  RGKN_FIRST = 32; // ofset zum ersten RGKN-Block

type

  // CREG-block (am anfang des hives)
  PCREG_HEADER = ^TCREG_HEADER;
  TCREG_HEADER = packed record
    id, // id, muss ID_CREG "creg" sein
      dummy1,
      ofs_root, // ofset zum 1. RGDB-block
      dummy2,
      entries: DWORD; // anzahl der RGDB-blcke
  end;

  // RGKN-block (nach CREG an pos 32, enthlt navigationsstruktur des hives)
  PRGKN_BLOCK = ^TRGKN_BLOCK;
  TRGKN_BLOCK = packed record
    id, // id, muss ID_RGKN "rgkn" sein
      size, // gre der struktur
      ofs_root: DWORD; // ofset des 1. TREE-eintrags (relativ zu RGKN!)
  end;

  // TREE-block (enthlt informationen zu einem registry-schlssel,
  //             mehrere nach RGKN-block)
  PTREE_BLOCK = ^TTREE_BLOCK;
  TTREE_BLOCK = packed record
    dummy1,
      hash, // hash des keynamens, siehe winreg.txt
      dummy2: DWORD;
    ofsParent, // zeiger auf bergeordneten schlssel
      ofsSub, // zeiger auf 1. sub-key (oder $FFFFFFFF /
                       // $00000000, falls keiner vorhanden)
    ofsNext: DWORD; // zeiger auf nchsten schlssel im gleichen
                       // level (oder $FFFFFFFF / $00000000, falls letzter)
    id: DWORD; // id des dazugehrigen RGDB-eintrages
  end;

  // RGDB-block (enthlt die eigentlichen schlssel/werte-eintrge,
  //             dies ist der header)
  PRGDB_HEADER = ^TRGDB_HEADER;
  TRGDB_HEADER = packed record
    id, // id, muss ID_RGDB "rgdb" sein
      size: DWORD; // gre der struktur
  end;

  // virt. RGDB-eintrag (enthlt die tatschlichen schlssel-infos,
  //                    _keine_ hive-struktur, wird vom programm erzeugt)
  PRGDBENTRY = ^TRGDBENTRY;
  TRGDBENTRY = packed record
    size, // gre des eintrages
      id, // die id des eintrags, korrespondiert mit
                       // id in TTREE_BLOCK
    dummy1: DWORD;
    len_key, // lnge des schlsselnamens
      num_vals: Word; // anzahl der wert-eintrge
    dummy2: DWORD;
    key_name: string; // schlssel-name
    data: PByteArray; // zeiger auf wert-daten
  end;

  // tats. RGDB-eintrag (enthlt die tatschlichen schlssel-infos, steht
  //                     so im hive)
  // daran schlieen sich der schlsselname und die werte-daten
  // (in form von (TVALUE_ENTRY+Daten)[0..x]) an
  PRGDB_ENTRY = ^TRGDB_ENTRY;
  TRGDB_ENTRY = packed record
    size, // gre des eintrages
      id, // mit TREE_BLOCK.id korrespondierende id des eintrages
      dummy1: DWORD;
    len_key, // lnge key-name
      num_vals: Word; // anzahl werte
    dummy2: DWORD;
  end;

  // VALUE-eintrag, enthlt angaben zu einem registry-wert
  // daran schlieen sich der wertname sowie die daten des wertes an
  PVALUE_ENTRY = ^TVALUE_ENTRY;
  TVALUE_ENTRY = packed record
    type_val, // typ des wertes (REG_NONE,REG_SZ...)
      dummy1: DWORD; // unbekannt
    len_val, // gre des wert-namens
      len_data: Word; // gre der wert-daten
  end;

implementation
end.
